@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from lgdo import lh5
+
 from . import build_hit, core, iterator, math, shape
 from ._version import version as __version__
 
@@ -15,3 +17,5 @@ __all__ = [
     "optmap",
     "shape",
 ]
+
+lh5.settings.DEFAULT_HDF5_SETTINGS = {"shuffle": True, "compression": "lzf"}
